@@ -21,7 +21,7 @@ from aliyunsdkcore.request import RpcRequest
 class GetJobTopologyRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'TeslaStream', '2018-01-15', 'GetJobTopology')
+		RpcRequest.__init__(self, 'TeslaStream', '2018-01-15', 'GetJobTopology','teslastream')
 
 	def get_JobName(self):
 		return self.get_query_params().get('JobName')
